// Copyright (C) 2019  Wilko Manger
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

import 'package:matrix_sdk/src/event/room/room_event.dart';
import 'package:matrix_sdk/src/event/room/state/state_event.dart';
import 'package:meta/meta.dart';

import '../../../identifier.dart';

class AliasesChangeEvent extends StateEvent {
  @override
  final AliasesChange content;

  AliasesChangeEvent(
    this.content,
    RoomEventArgs args, {
    @required String stateKey,
  }) : super(args, stateKey: stateKey);

  factory AliasesChangeEvent.fromJson(RoomEventArgs args, dynamic json) {
    if (!hasStateKey(json)) {
      return null;
    }

    final content = json['content'];
    var aliases = content['aliases'] as List<dynamic>;

    var convertedAliases;
    if (aliases != null) {
      convertedAliases = aliases
          .map(
            (a) => RoomAlias.isValidFullyQualified(a) ? RoomAlias(a) : null,
          )
          .where((a) => a != null)
          .toList(growable: false);
    }

    return AliasesChangeEvent(
      AliasesChange(
        aliases: convertedAliases,
      ),
      args,
      stateKey: json['state_key'],
    );
  }
}

class AliasesChange extends StateEventContent {
  final List<RoomAlias> aliases;

  AliasesChange({@required this.aliases});

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'aliases': aliases?.map((a) => a.toString())?.toList(growable: false),
    });
}
