// Copyright (C) 2019  Wilko Manger
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

import 'package:matrix_sdk/src/event/room/room_event.dart';
import 'package:matrix_sdk/src/event/room/state/state_event.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:meta/meta.dart';

class RoomUpgradeEvent extends StateEvent {
  @override
  final RoomUpgrade content;

  RoomUpgradeEvent(this.content, RoomEventArgs args)
      : super(args, stateKey: '');

  factory RoomUpgradeEvent.fromJson(RoomEventArgs args, dynamic json) {
    if (!hasStateKey(json)) {
      return null;
    }

    final content = json['content'];

    final body = content['body'];
    var replacementRoomId = content['replacement_room'];
    if (replacementRoomId == null) {
      return null;
    }

    replacementRoomId = RoomId(replacementRoomId);

    return RoomUpgradeEvent(
      RoomUpgrade(
        body: body,
        replacementRoomId: replacementRoomId,
      ),
      args,
    );
  }
}

class RoomUpgrade extends StateEventContent {
  final String body;

  final RoomId replacementRoomId;

  RoomUpgrade({
    @required this.body,
    @required this.replacementRoomId,
  });

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'body': body,
      'replacement_room': replacementRoomId.toString(),
    });
}
