// Copyright (C) 2019  Wilko Manger
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

import 'package:matrix_sdk/src/event/room/room_event.dart';
import 'package:matrix_sdk/src/event/room/state/state_event.dart';
import 'package:meta/meta.dart';

class TopicChangeEvent extends StateEvent {
  @override
  final TopicChange content;

  TopicChangeEvent(this.content, RoomEventArgs args)
      : super(args, stateKey: '');

  factory TopicChangeEvent.fromJson(RoomEventArgs args, dynamic json) {
    if (!hasStateKey(json)) {
      return null;
    }

    final content = json['content'];
    final body = content['topic'];

    return TopicChangeEvent(
      TopicChange(
        topic: body,
      ),
      args,
    );
  }
}

class TopicChange extends StateEventContent {
  final String topic;

  TopicChange({@required this.topic});

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'topic': topic,
    });
}
