// Copyright (C) 2019  Wilko Manger
// Copyright (C) 2019  Mathieu Velten
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

import 'dart:async';
import 'dart:convert';

import 'package:kiwi/kiwi.dart';
import 'package:matrix_sdk/src/api/client.dart';
import 'package:matrix_sdk/src/storables.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/room/room.dart';
import 'package:meta/meta.dart';

import '../user.dart';

/// Sort order: Alphabetical (a-z) on [Room.id].
class Rooms extends Storables<RoomId, Room> {
  final ClientService _client;

  Rooms(String scope)
      : _client = Container().resolve<ClientService>(scope),
        super(scope);

  @override
  @protected
  Future<Room> getSingleFromStore(RoomId id) => store?.getRoom(id);

  @override
  @protected
  Future<Iterable<Room>> getFromStore({Room from, int count}) async =>
      store?.getRooms(from: from, count: count);

  @override
  @protected
  Future<int> getSavedInStoreCount() => store?.getRoomCount();

  @override
  @protected
  Future<void> setInStore(Iterable<Room> rooms) => store?.setRooms(rooms);

  @override
  Future<Iterable<Room>> getFromRemote({int count}) async => [];

  @protected
  Iterable<Room> sort(Iterable<Room> items) => items.toList(growable: false)
    ..sort((Room a, Room b) => a.id.toString().compareTo(b.id.toString()));

  /// Create a room.
  Future<RoomId> create({
    String name,
    String topic,
    List<User> invitees,
  }) async {
    final Map<String, dynamic> body = {'preset': 'public_chat'};

    if (name != null) {
      body['name'] = name;
    }

    if (topic != null) {
      body['topic'] = topic;
    }

    if (invitees != null) {
      final inviteeIds = List<String>();

      inviteeIds.addAll(invitees.map((user) => user.id.toString()));

      body['invite'] = inviteeIds;
    }

    final response = await _client.createRoom(body: json.encode(body));

    if (response.statusCode == 200) {
      final body = json.decode(response.body);

      return RoomId(body['room_id']);
    } else {
      throw response;
    }
  }
}
